svn commit: r963632 - in /subversion/trunk/subversion: include/svn_wc.h libsvn_wc/deprecated.c libsvn_wc/translate.c

2010-07-13 Thread hwright
Author: hwright
Date: Tue Jul 13 09:40:34 2010
New Revision: 963632

URL: http://svn.apache.org/viewvc?rev=963632view=rev
Log:
Remove the public libsvn_wc file and stream translation APIs (while leaving
their deprecated predecessors).  These APIs are not consumed by the client.
See: http://svn.haxx.se/dev/archive-2010-07/0100.shtml

* subversion/include/svn_wc.h
  (svn_wc_translated_file3, svn_wc_translated_stream2): Remove.
  (svn_wc_translated_file2, svn_wc_translated_stream): Restore the docs to
their pre-rev state.

* subversion/libsvn_wc/deprecated.c
  (svn_wc_translated_stream, svn_wc_translated_file2): Use the library-internal
APIs, rather than the now-removed public ones.

* subversion/libsvn_wc/translate.c
  (svn_wc_translated_stream2, svn_wc_translated_file3): Remove.

Modified:
subversion/trunk/subversion/include/svn_wc.h
subversion/trunk/subversion/libsvn_wc/deprecated.c
subversion/trunk/subversion/libsvn_wc/translate.c

Modified: subversion/trunk/subversion/include/svn_wc.h
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_wc.h?rev=963632r1=963631r2=963632view=diff
==
--- subversion/trunk/subversion/include/svn_wc.h (original)
+++ subversion/trunk/subversion/include/svn_wc.h Tue Jul 13 09:40:34 2010
@@ -6984,10 +6984,10 @@ svn_wc_create_tmp_file(apr_file_t **fp,
 
 /* EOL conversion and keyword expansion. */
 
-/** Set @a xlated_abspath to a translated copy of @a src
+/** Set @a xlated_path to a translated copy of @a src
  * or to @a src itself if no translation is necessary.
- * That is, if @a versioned_abspath's properties indicate newline conversion
- * or keyword expansion, point @a *xlated_abspath to a copy of @a src
+ * That is, if @a versioned_file's properties indicate newline conversion or
+ * keyword expansion, point @a *xlated_path to a copy of @a src
  * whose newlines and keywords are converted using the translation
  * as requested by @a flags.
  *
@@ -7004,40 +7004,20 @@ svn_wc_create_tmp_file(apr_file_t **fp,
  * #SVN_WC_TRANSLATE_FORCE_COPY flag in @a flags.
  *
  * This function is generally used to get a file that can be compared
- * meaningfully against @a versioned_abspath's text base, if
- * #SVN_WC_TRANSLATE_TO_NF is specified, against @a versioned_abspath itself
- * if #SVN_WC_TRANSLATE_FROM_NF is specified.
- *
- * The output file is created in the temp file area belonging to
- * @a versioned_abspath. By default it will be deleted at result_pool
- * cleanup. If @a flags includes #SVN_WC_TRANSLATE_NO_OUTPUT_CLEANUP,
- * the default result_pool cleanup handler to remove @a *xlated_abspath is
- * not registered.
+ * meaningfully against @a versioned_file's text base, if
+ * @c SVN_WC_TRANSLATE_TO_NF is specified, against @a versioned_file itself
+ * if @c SVN_WC_TRANSLATE_FROM_NF is specified.
  *
- * If an error is returned, the effect on @a *xlated_abspath is undefined.
+ * Output files are created in the temp file area belonging to
+ * @a versioned_file.  By default they will be deleted at pool cleanup.
  *
- * @since New in 1.7.
- */
-svn_error_t *
-svn_wc_translated_file3(const char **xlated_abspath,
-const char *src,
-svn_wc_context_t *wc_ctx,
-const char *versioned_abspath,
-apr_uint32_t flags,
-svn_cancel_func_t cancel_func,
-void *cancel_baton,
-apr_pool_t *result_pool,
-apr_pool_t *scratch_pool);
-
-
-/** Similar to svn_wc_translated_file3(), but with an adm_access baton
- * and relative paths instead of a wc_context and absolute paths, with
- * a single pool, and no cancellation func/baton.
+ * If @c SVN_WC_TRANSLATE_NO_OUTPUT_CLEANUP is specified, the default
+ * pool cleanup handler to remove @a *xlated_path is not registered.
  *
- * @since New in 1.4.
- * @deprecated Provided for compatibility with the 1.6 API
+ * If an error is returned, the effect on @a *xlated_path is undefined.
+ *
+ * @since New in 1.4
  */
-SVN_DEPRECATED
 svn_error_t *
 svn_wc_translated_file2(const char **xlated_path,
 const char *src,
@@ -7061,10 +7041,9 @@ svn_wc_translated_file(const char **xlat
apr_pool_t *pool);
 
 
-/** Set @a stream to a stream allocated in @a result_pool, that will
- * translate *to* normal form while reading, or *from* normal form while
- * writing @a local_abspath.  The translation will take the file properties
- * from @a versioned_abspath using @a wc_ctx.
+/** Returns a @a stream allocated in @a pool with access to the given
+ * @a path taking the file properties from @a versioned_file using
+ * @a adm_access.
  *
  * If @a flags includes #SVN_WC_TRANSLATE_FROM_NF, the stream will
  * translate from Normal Form to working copy form while writing to
@@ -7076,26 +7055,8 @@ 

svn commit: r963665 - /subversion/trunk/subversion/include/svn_wc.h

2010-07-13 Thread hwright
Author: hwright
Date: Tue Jul 13 10:32:18 2010
New Revision: 963665

URL: http://svn.apache.org/viewvc?rev=963665view=rev
Log:
* subversion/include/svn_wc.h
  (svn_wc_translated_file2, svn_wc_translated_stream): Re-deprecate these
functions, in followup to r963632.

Modified:
subversion/trunk/subversion/include/svn_wc.h

Modified: subversion/trunk/subversion/include/svn_wc.h
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_wc.h?rev=963665r1=963664r2=963665view=diff
==
--- subversion/trunk/subversion/include/svn_wc.h (original)
+++ subversion/trunk/subversion/include/svn_wc.h Tue Jul 13 10:32:18 2010
@@ -7018,6 +7018,7 @@ svn_wc_create_tmp_file(apr_file_t **fp,
  *
  * @since New in 1.4
  */
+SVN_DEPRECATED
 svn_error_t *
 svn_wc_translated_file2(const char **xlated_path,
 const char *src,
@@ -7057,6 +7058,7 @@ svn_wc_translated_file(const char **xlat
  *
  * @since New in 1.5.
  */
+SVN_DEPRECATED
 svn_error_t *
 svn_wc_translated_stream(svn_stream_t **stream,
  const char *path,




svn commit: r963676 - /subversion/trunk/subversion/libsvn_wc/copy.c

2010-07-13 Thread hwright
Author: hwright
Date: Tue Jul 13 10:57:24 2010
New Revision: 963676

URL: http://svn.apache.org/viewvc?rev=963676view=rev
Log:
* subversion/libsvn_wc/copy.c
  (copy_versioned_dir): Update a deprecated API use.

Modified:
subversion/trunk/subversion/libsvn_wc/copy.c

Modified: subversion/trunk/subversion/libsvn_wc/copy.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/copy.c?rev=963676r1=963675r2=963676view=diff
==
--- subversion/trunk/subversion/include/svn_io.h (original)
+++ subversion/trunk/subversion/include/svn_io.h Tue Jul 13 12:43:55 2010
@@ -1371,7 +1371,9 @@ svn_io_remove_dir(const char *path,
  * apr_dir_read() are NOT returned in the hash.
  *
  * @since New in 1.4.
+ * @deprecated Provided for backward compatibility with the 1.6 API.
  */
+SVN_DEPRECATED
 svn_error_t *
 svn_io_get_dir_filenames(apr_hash_t **dirents,
  const char *path,

Modified: subversion/trunk/subversion/libsvn_subr/io.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_subr/io.c?rev=963697r1=963696r2=963697view=diff
==
--- subversion/trunk/subversion/libsvn_subr/io.c (original)
+++ subversion/trunk/subversion/libsvn_subr/io.c Tue Jul 13 12:43:55 2010
@@ -1976,44 +1976,8 @@ svn_io_get_dir_filenames(apr_hash_t **di
  const char *path,
  apr_pool_t *pool)
 {
-  apr_status_t status;
-  apr_dir_t *this_dir;
-  apr_finfo_t this_entry;
-  apr_int32_t flags = APR_FINFO_NAME;
-
-  *dirents = apr_hash_make(pool);
-
-  SVN_ERR(svn_io_dir_open(this_dir, path, pool));
-
-  for (status = apr_dir_read(this_entry, flags, this_dir);
-   status == APR_SUCCESS;
-   status = apr_dir_read(this_entry, flags, this_dir))
-{
-  if ((this_entry.name[0] == '.')
-   ((this_entry.name[1] == '\0')
-  || ((this_entry.name[1] == '.')
-   (this_entry.name[2] == '\0'
-{
-  continue;
-}
-  else
-{
-  const char *name;
-  SVN_ERR(entry_name_to_utf8(name, this_entry.name, path, pool));
-  apr_hash_set(*dirents, name, APR_HASH_KEY_STRING, name);
-}
-}
-
-  if (! (APR_STATUS_IS_ENOENT(status)))
-return svn_error_wrap_apr(status, _(Can't read directory '%s'),
-  svn_dirent_local_style(path, pool));
-
-  status = apr_dir_close(this_dir);
-  if (status)
-return svn_error_wrap_apr(status, _(Error closing directory '%s'),
-  svn_dirent_local_style(path, pool));
-
-  return SVN_NO_ERROR;
+  return svn_error_return(svn_io_get_dirents3(dirents, path, TRUE,
+  pool, pool));
 }
 
 svn_io_dirent2_t *




svn commit: r963712 - in /subversion/trunk/subversion: libsvn_client/commit.c libsvn_fs_fs/fs_fs.c libsvn_wc/adm_crawler.c libsvn_wc/adm_ops.c libsvn_wc/upgrade.c mod_dav_svn/repos.c

2010-07-13 Thread hwright
Author: hwright
Date: Tue Jul 13 13:35:37 2010
New Revision: 963712

URL: http://svn.apache.org/viewvc?rev=963712view=rev
Log:
Replaces uses of the deprecated svn_io_get_dirents2() and
svn_io_get_dir_filenames() with svn_io_get_dirents3(), appropriately checking
for only the name and type information.

* subversion/mod_dav_svn/repos.c
  (deliver),
* subversion/libsvn_wc/adm_ops.c
  (erase_from_wc),
* subversion/libsvn_wc/adm_crawler.c
  (report_revisions_and_depths),
* subversion/libsvn_wc/upgrade.c
  (read_many_wcprops, migrate_text_bases),
* subversion/libsvn_client/commit.c
  (import_dir),
* subversion/libsvn_fs_fs/fs_fs.c
  (svn_fs_fs__list_transactions):
Update deprecated calls.

Modified:
subversion/trunk/subversion/libsvn_client/commit.c
subversion/trunk/subversion/libsvn_fs_fs/fs_fs.c
subversion/trunk/subversion/libsvn_wc/adm_crawler.c
subversion/trunk/subversion/libsvn_wc/adm_ops.c
subversion/trunk/subversion/libsvn_wc/upgrade.c
subversion/trunk/subversion/mod_dav_svn/repos.c

Modified: subversion/trunk/subversion/libsvn_client/commit.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/commit.c?rev=963712r1=963711r2=963712view=diff
==
--- subversion/trunk/subversion/libsvn_client/commit.c (original)
+++ subversion/trunk/subversion/libsvn_client/commit.c Tue Jul 13 13:35:37 2010
@@ -309,7 +309,7 @@ import_dir(const svn_delta_editor_t *edi
   if (!no_ignore)
 SVN_ERR(svn_wc_get_default_ignores(ignores, ctx-config, pool));
 
-  SVN_ERR(svn_io_get_dirents2(dirents, path, pool));
+  SVN_ERR(svn_io_get_dirents3(dirents, path, TRUE, pool, pool));
 
   for (hi = apr_hash_first(pool, dirents); hi; hi = apr_hash_next(hi))
 {

Modified: subversion/trunk/subversion/libsvn_fs_fs/fs_fs.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_fs/fs_fs.c?rev=963712r1=963711r2=963712view=diff
==
--- subversion/trunk/subversion/libsvn_fs_fs/fs_fs.c (original)
+++ subversion/trunk/subversion/libsvn_fs_fs/fs_fs.c Tue Jul 13 13:35:37 2010
@@ -7019,7 +7019,7 @@ svn_fs_fs__list_transactions(apr_array_h
   txn_dir = svn_dirent_join(fs-path, PATH_TXNS_DIR, pool);
 
   /* Now find a listing of this directory. */
-  SVN_ERR(svn_io_get_dirents2(dirents, txn_dir, pool));
+  SVN_ERR(svn_io_get_dirents3(dirents, txn_dir, TRUE, pool, pool));
 
   /* Loop through all the entries and return anything that ends with '.txn'. */
   for (hi = apr_hash_first(pool, dirents); hi; hi = apr_hash_next(hi))

Modified: subversion/trunk/subversion/libsvn_wc/adm_crawler.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/adm_crawler.c?rev=963712r1=963711r2=963712view=diff
==
--- subversion/trunk/subversion/libsvn_wc/adm_crawler.c (original)
+++ subversion/trunk/subversion/libsvn_wc/adm_crawler.c Tue Jul 13 13:35:37 2010
@@ -241,7 +241,8 @@ report_revisions_and_depths(svn_wc__db_t
   dir_abspath = svn_dirent_join(anchor_abspath, dir_path, scratch_pool);
   SVN_ERR(svn_wc__db_base_get_children(base_children, db, dir_abspath,
scratch_pool, iterpool));
-  SVN_ERR(svn_io_get_dir_filenames(dirents, dir_abspath, scratch_pool));
+  SVN_ERR(svn_io_get_dirents3(dirents, dir_abspath, TRUE,
+  scratch_pool, scratch_pool));
 
   /*** Do the real reporting and recursing. ***/
 

Modified: subversion/trunk/subversion/libsvn_wc/adm_ops.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/adm_ops.c?rev=963712r1=963711r2=963712view=diff
==
--- subversion/trunk/subversion/libsvn_wc/adm_ops.c (original)
+++ subversion/trunk/subversion/libsvn_wc/adm_ops.c Tue Jul 13 13:35:37 2010
@@ -755,7 +755,8 @@ erase_from_wc(svn_wc__db_t *db,
 }
 
   /* Now handle any remaining unversioned items */
-  err = svn_io_get_dirents2(unversioned, local_abspath, scratch_pool);
+  err = svn_io_get_dirents3(unversioned, local_abspath, TRUE,
+scratch_pool, scratch_pool);
   if (err)
 {
   svn_pool_destroy(iterpool);

Modified: subversion/trunk/subversion/libsvn_wc/upgrade.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/upgrade.c?rev=963712r1=963711r2=963712view=diff
==
--- subversion/trunk/subversion/libsvn_wc/upgrade.c (original)
+++ subversion/trunk/subversion/libsvn_wc/upgrade.c Tue Jul 13 13:35:37 2010
@@ -173,7 +173,8 @@ read_many_wcprops(apr_hash_t **all_wcpro
 scratch_pool);
 
   /* Now walk the wcprops directory. */
-  SVN_ERR(svn_io_get_dirents2(dirents, props_dir_abspath, 

svn propchange: r963443 - svn:log

2010-07-13 Thread arfrever
Author: arfrever
Revision: 963443
Modified property: svn:log

Modified: svn:log at Tue Jul 13 13:46:46 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 13:46:46 2010
@@ -1,13 +1,7 @@
 Follow-up to r875957, check for rb_errinfo() when using Ruby 1.9 on Windows.
-
 Define HAVE_RB_ERRINFO if rb_errinfo() is available.
 
 * build/generator/gen_win.py
-  
   Import string.
-
   (get_win_defines): Define HAVE_RB_ERRINFO if rb_errinfo() is available.
-
   (_find_ruby): Get the version of Ruby we are linking to.
-
-  



svn commit: r963717 - in /subversion/branches/1.6.x: ./ CHANGES STATUS subversion/libsvn_wc/props.c subversion/tests/cmdline/merge_tests.py

2010-07-13 Thread hwright
Author: hwright
Date: Tue Jul 13 14:04:10 2010
New Revision: 963717

URL: http://svn.apache.org/viewvc?rev=963717view=rev
Log:
Merge r961970 from trunk:

 * r961970
   Clarify an error message.
   Justification:
 Makes it far easier to diagnose a faulty [auto-props] configuration.
 One-liner.
   Votes:
 +1: danielsh, stsp, hwright

Modified:
subversion/branches/1.6.x/   (props changed)
subversion/branches/1.6.x/CHANGES   (props changed)
subversion/branches/1.6.x/STATUS
subversion/branches/1.6.x/subversion/libsvn_wc/props.c
subversion/branches/1.6.x/subversion/tests/cmdline/merge_tests.py   (props 
changed)

Propchange: subversion/branches/1.6.x/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Tue Jul 13 14:04:10 2010
@@ -81,4 +81,4 @@
 /subversion/branches/tc_url_rev:874351-874483
 /subversion/branches/tree-conflicts:868291-873154
 /subversion/branches/tree-conflicts-notify:873926-874008
-/subversion/trunk:875965,875968,876004,876012,876017,876019,876022,876024,876032,876041-876042,876048,876051,876055-876056,876059,876083,876091,876097,876101,876104,876109,876123-876125,876129,876132,876138,876160,876167,876175,876180,876185,876205,876223-876225,876230,876233,876245,876252,876256,876283,876287,876312,876326-876327,876330,876366,876372,876374,876376,876383,876386,876442,876456-876457,876462-876464,876467,876469,876480,876486,876495-876497,876516-876518,876524,876526,876583,876601,876614,876628,876633,876641,876659,876687,876689,876705,876715,876726,876760,876763,876794,876804,876815-876816,876821,876825,876837,876840-876841,876843,876849,876857-876858,876862,876873,876890,876897,876905,876908,876925,876931,876934,876948-876949,876953,876987,876993,877011,877014,877016,877028-877029,877038,877119,877127,877146,877157,877191,877195,877203,877211,877230,877234,877237,877243,877249,877259,877261,877304,877319,877407,877437,877441-877442,877453,877459,877472,87754
 
4,877553,877565,877568,877573,877593,877595,877597,877601,877612,877665,877667,877681,877692,877696,877701,877720,877730,877784,877793,877797,877809,877815,877819,877821,877842,877848,877853,877867,877869,877873,877901,877909,877916,877931,877942,877953,877964,877968,877970,877981-877982,878005,878013,878015,878020,878046,878053,878062,878074,878080,878089,878091,878093,878095,878127,878129,878131,878142,878173-878176,878216,878240,878242,878255,878269,878272,878279,878296-878297,878303,878321,878335,878338,878341,878343,878353,878364,878367-878368,878385,878399,878423,878426,878447,878462,878484,878491,878498,878532,878595,878646,878659,878673,878682-878683,878690-878691,878693,878723,878760-878761,878873,878875,878877,878879,878905,878910-878911,878915-878916,878924-878925,878946,878949,878955,878960,878970,878981,879001,879033,879056,879074,879076,879081-879082,879093,879105,879126,879148,879170,879198-879199,879201,879271,879293,879357,879375-879376,879403,879631,879635-
 
879636,879688,879709-879711,879747,879902,879916,879954,879961,879966,879971,880082,880095,880105,880162,880226,880274-880275,880370,880450,880461,880474,880525-880526,880552,881905,884842,886164,886197,888715,888979,889081,889840,891672,892050,892085,895514,895653,896522,896915,898048,898963,899826,899828,900797,901304,901752,902093,904301,904394,904594,905303,905326,906256,906305,906587,908980-908981,917640,918211,922516,923389,923391,926151,926167,927323,927328,931209,931211,931392,931568,932942,933299,934599,934603,935631,935992,935996,937610,939375-939376,944635,950931,950933,951753,952992,953317
+/subversion/trunk:875965,875968,876004,876012,876017,876019,876022,876024,876032,876041-876042,876048,876051,876055-876056,876059,876083,876091,876097,876101,876104,876109,876123-876125,876129,876132,876138,876160,876167,876175,876180,876185,876205,876223-876225,876230,876233,876245,876252,876256,876283,876287,876312,876326-876327,876330,876366,876372,876374,876376,876383,876386,876442,876456-876457,876462-876464,876467,876469,876480,876486,876495-876497,876516-876518,876524,876526,876583,876601,876614,876628,876633,876641,876659,876687,876689,876705,876715,876726,876760,876763,876794,876804,876815-876816,876821,876825,876837,876840-876841,876843,876849,876857-876858,876862,876873,876890,876897,876905,876908,876925,876931,876934,876948-876949,876953,876987,876993,877011,877014,877016,877028-877029,877038,877119,877127,877146,877157,877191,877195,877203,877211,877230,877234,877237,877243,877249,877259,877261,877304,877319,877407,877437,877441-877442,877453,877459,877472,87754
 

svn commit: r963726 - /subversion/trunk/subversion/bindings/javahl/tests/org/apache/subversion/javahl/BasicTests.java

2010-07-13 Thread hwright
Author: hwright
Date: Tue Jul 13 14:25:56 2010
New Revision: 963726

URL: http://svn.apache.org/viewvc?rev=963726view=rev
Log:
Comment out a JavaHL test, pending the resolution of issue #3680.

* subversion/bindings/javahl/tests/org/apache/subversion/javahl/BasicTests.java
  (testObstructionTolerance): Coment out (the poor-man's Xfail).

Modified:

subversion/trunk/subversion/bindings/javahl/tests/org/apache/subversion/javahl/BasicTests.java

Modified: 
subversion/trunk/subversion/bindings/javahl/tests/org/apache/subversion/javahl/BasicTests.java
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/bindings/javahl/tests/org/apache/subversion/javahl/BasicTests.java?rev=963726r1=963725r2=963726view=diff
==
--- 
subversion/trunk/subversion/bindings/javahl/tests/org/apache/subversion/javahl/BasicTests.java
 (original)
+++ 
subversion/trunk/subversion/bindings/javahl/tests/org/apache/subversion/javahl/BasicTests.java
 Tue Jul 13 14:25:56 2010
@@ -3244,6 +3244,11 @@ public class BasicTests extends SVNTests
  * @throws IOException
  * @throws SubversionException
  */
+/*
+  This is currently commented out, because we don't have an XFail method
+  for JavaHL.  The resolution is pending the result of issue #3680:
+  http://subversion.tigris.org/issues/show_bug.cgi?id=3680
+
 public void testObstructionTolerance()
 throws SubversionException, IOException
 {
@@ -3400,7 +3405,7 @@ public class BasicTests extends SVNTests

backupTest.getWc().getItemContent(A/D/H/omega));
 
 backupTest.checkStatus();
-}
+}*/
 
 /**
  * Test basic blame functionality.  This test marginally tests blame




svn commit: r963734 - /subversion/trunk/subversion/bindings/swig/ruby/test/test_client.rb

2010-07-13 Thread hwright
Author: hwright
Date: Tue Jul 13 14:32:43 2010
New Revision: 963734

URL: http://svn.apache.org/viewvc?rev=963734view=rev
Log:
* subversion/bindings/swig/ruby/test/test_client.rb
  (test_cleanup): Comment out, another casuality of issue #3680.

Modified:
subversion/trunk/subversion/bindings/swig/ruby/test/test_client.rb

Modified: subversion/trunk/subversion/bindings/swig/ruby/test/test_client.rb
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/bindings/swig/ruby/test/test_client.rb?rev=963734r1=963733r2=963734view=diff
==
--- subversion/trunk/subversion/bindings/swig/ruby/test/test_client.rb 
(original)
+++ subversion/trunk/subversion/bindings/swig/ruby/test/test_client.rb Tue Jul 
13 14:32:43 2010
@@ -1079,6 +1079,12 @@ class SvnClientTest  Test::Unit::TestCa
 end
   end
 
+=begin
+  We haven't yet figured out what to expect in the case of an obstruction,
+  but it is no longer an error.  Commenting out this test until that
+  decision is made (see issue #3680:
+  http://subversion.tigris.org/issues/show_bug.cgi?id=3680)
+
   def test_cleanup
 log = sample log
 file = sample.txt
@@ -1124,6 +1130,7 @@ class SvnClientTest  Test::Unit::TestCa
   end
 end
   end
+=end
 
   def test_relocate
 log = sample log




svn commit: r963741 - /subversion/trunk/subversion/libsvn_client/cmdline.c

2010-07-13 Thread stsp
Author: stsp
Date: Tue Jul 13 14:46:05 2010
New Revision: 963741

URL: http://svn.apache.org/viewvc?rev=963741view=rev
Log:
* subversion/libsvn_client/cmdline.c:
  (check_root_url_of_target): Catch SVN_ERR_WC_PATH_NOT_FOUND in addition
  to other similar error codes, allowing argument processing to continue
  as expected.

Patch by: Uwe Stuehler (subversion-li...@bsdx.de)
log message tweaked by me

Modified:
subversion/trunk/subversion/libsvn_client/cmdline.c

Modified: subversion/trunk/subversion/libsvn_client/cmdline.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/cmdline.c?rev=963741r1=963740r2=963741view=diff
==
--- subversion/trunk/subversion/libsvn_client/cmdline.c (original)
+++ subversion/trunk/subversion/libsvn_client/cmdline.c Tue Jul 13 14:46:05 2010
@@ -123,6 +123,7 @@ check_root_url_of_target(const char **ro
* argument.
*/
   if ((err-apr_err == SVN_ERR_ENTRY_NOT_FOUND)
+  || (err-apr_err == SVN_ERR_WC_PATH_NOT_FOUND)
   || (err-apr_err == SVN_ERR_WC_NOT_WORKING_COPY))
 {
   svn_error_clear(err);




svn propchange: r948379 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 948379
Modified property: svn:log

Modified: svn:log at Tue Jul 13 14:57:24 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 14:57:24 2010
@@ -5,4 +5,4 @@ reason I did it had also already been ma
   (log_do_committed): Use the full original code path for determining the
 'last mod time' to store.
 
-Suggested by: philipm
+Suggested by: philip



svn propchange: r947997 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 947997
Modified property: svn:log

Modified: svn:log at Tue Jul 13 14:57:35 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 14:57:35 2010
@@ -1,4 +1,4 @@
 * subversion/libsvn_wc/adm_files.c
   (svn_wc__get_pristine_contents): Fix an error leak.
 
-Found by: philipm
+Found by: philip



svn propchange: r958005 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 958005
Modified property: svn:log

Modified: svn:log at Tue Jul 13 14:57:11 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 14:57:11 2010
@@ -6,4 +6,4 @@ Follow-up to r957936. Fix wrong order of
 * subversion/libsvn_wc/node.c
   (svn_wc__node_get_repos_relpath): Fix wrong order of arguments.
 
-Found by: philipm
+Found by: philip



svn propchange: r948916 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 948916
Modified property: svn:log

Modified: svn:log at Tue Jul 13 14:58:31 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 14:58:31 2010
@@ -1,7 +1,7 @@
 Bring the JavaHL verification API into some state of modernness.
 
 Found by: John Chambers john.chamb...@wandisco.com
-Suggested by: julianf
+Suggested by: julianfoad
 
 * subversion/bindings/javahl/native/SVNAdmin.cpp
   (verify): Use the verify API, rather than just doing a 
dump-and-ignore-output.



svn propchange: r927328 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 927328
Modified property: svn:log

Modified: svn:log at Tue Jul 13 14:59:00 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 14:59:00 2010
@@ -1,4 +1,4 @@
 * subversion/libsvn_subr/atomic.c
   (svn_atomic__init_once): Following up on r927323, add comment.
 
-Suggested by: julianf
+Suggested by: julianfoad



svn propchange: r927323 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 927323
Modified property: svn:log

Modified: svn:log at Tue Jul 13 14:59:11 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 14:59:11 2010
@@ -6,7 +6,7 @@ Julian identified that we just ignore sq
 SVN_ERR_SQLITE_ERROR in wc_db.c if we are looking for a database. This
 patch makes it unlikely that we make the same mistake in future cases.
 
-Found by: julianf
+Found by: julianfoad
 
 * subversion/libsvn_subr/atomic.c
   (svn_atomic__init_once): Wrap the error returned from the initialization



svn propchange: r959115 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 959115
Modified property: svn:log

Modified: svn:log at Tue Jul 13 14:59:43 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 14:59:43 2010
@@ -4,4 +4,4 @@ Fix something in r959112.
   (svn_wc__node_get_copyfrom_info):
 Use relpath_join instead of dirent_join in one place.
 
-Suggested by: Bert
+Suggested by: rhuijben



svn propchange: r943683 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 943683
Modified property: svn:log

Modified: svn:log at Tue Jul 13 15:00:02 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 15:00:02 2010
@@ -14,5 +14,5 @@ it again in the callback.
assemble_unversioned): Initialize status-changelist.
   (svn_wc_dup_status3): Allocate space for the 'changelist' field.
 
-Suggested by: Bert
+Suggested by: rhuijben
   gstein



svn propchange: r870851 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 870851
Modified property: svn:log

Modified: svn:log at Tue Jul 13 15:01:04 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 15:01:04 2010
@@ -7,4 +7,4 @@ svndumpfilter drops mergeinfo when it is
 * subversion/tests/cmdline/svndumpfilter_tests.py
   (test_list): Remove XFail marker from 'svndumpfilter_loses_mergeinfo'.
 
-Found by: MSshu
+Found by: MsShu



svn propchange: r870850 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 870850
Modified property: svn:log

Modified: svn:log at Tue Jul 13 15:01:13 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 15:01:13 2010
@@ -5,4 +5,4 @@ svndumpfilter drops mergeinfo when it is
   (svndumpfilter_loses_mergeinfo): New function.
   (test_list): Add 'svndumpfilter_loses_mergeinfo' as XFail test.
 
-Found by: MSshu
+Found by: MsShu



svn propchange: r963741 - svn:log

2010-07-13 Thread stsp
Author: stsp
Revision: 963741
Modified property: svn:log

Modified: svn:log at Tue Jul 13 15:02:39 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 15:02:39 2010
@@ -3,5 +3,5 @@
   to other similar error codes, allowing argument processing to continue
   as expected.
 
-Patch by: Uwe Stuehler (subversion-li...@bsdx.de)
+Patch by: Uwe Stuehler subversion-li...@bsdx.de
 log message tweaked by me



svn propchange: r930662 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 930662
Modified property: svn:log

Modified: svn:log at Tue Jul 13 15:03:38 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 15:03:38 2010
@@ -16,4 +16,6 @@ into account both versioned and unversio
 svn_diff__close_patch() since we're creating targets to delete dirs
 and those have no associated patch.
 
-Review by: julianf, stsp, neels
+Review by: julianfoad
+   stsp
+   neels



svn propchange: r937296 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 937296
Modified property: svn:log

Modified: svn:log at Tue Jul 13 15:03:10 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 15:03:10 2010
@@ -5,4 +5,5 @@ Follow-up to r937033.
   (svn_repos_dump_fs3): Replace needless apr_psprintf with string literal.
Check for NULL progress_func.
 
-Suggested by: gstein, rhuijben
+Suggested by: gstein
+  rhuijben



svn propchange: r887178 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 887178
Modified property: svn:log

Modified: svn:log at Tue Jul 13 15:04:08 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 15:04:08 2010
@@ -11,5 +11,5 @@ characters, if any, from test failure me
   test failure messages.
 
 Approved by: julianfoad
-Reviewed by: julianfoad,
+Reviewed by: julianfoad
  brane



svn propchange: r917512 - svn:log

2010-07-13 Thread hwright
Author: hwright
Revision: 917512
Modified property: svn:log

Modified: svn:log at Tue Jul 13 15:04:25 2010
--
--- svn:log (original)
+++ svn:log Tue Jul 13 15:04:25 2010
@@ -7,4 +7,5 @@ Follow-up to r916286.
   (dav_svn__location_in_filter, dav_svn__location_body_filter):
Use 'svn_uri_canonicalize' on url paths.
 
-Found by: julianfoad, rhuijben
+Found by: julianfoad
+  rhuijben



svn commit: r963767 - /subversion/site/publish/docs/community-guide/releasing.part.html

2010-07-13 Thread cmpilato
Author: cmpilato
Date: Tue Jul 13 15:53:32 2010
New Revision: 963767

URL: http://svn.apache.org/viewvc?rev=963767view=rev
Log:
* site/publish/docs/community-guide/releasing.part.html
  (releasing-release): Update the website tweaking instructions, and
add a reminder to update our published API doc snapshots as part of
the release process, too.

Modified:
subversion/site/publish/docs/community-guide/releasing.part.html

Modified: subversion/site/publish/docs/community-guide/releasing.part.html
URL: 
http://svn.apache.org/viewvc/subversion/site/publish/docs/community-guide/releasing.part.html?rev=963767r1=963766r2=963767view=diff
==
--- subversion/site/publish/docs/community-guide/releasing.part.html (original)
+++ subversion/site/publish/docs/community-guide/releasing.part.html Tue Jul 13 
15:53:32 2010
@@ -1062,14 +1062,19 @@ freshmeat crew before it goes public./p
 
 pbUpdate the website/b/p
 ol
-  liEdit the www/project_status.html file appropriately in /trunk
-  *NOT* in the release branch and commit. Remember edit a search term
-  at the end of release's issue link./li
-  liUpdate the best available version on the front page and at the
-  top of www/getting.html/li
-  liUpdate the Latest Release section of www/index.html to point
-  to the new announcement./li
+  liEdit the ^/subversion/site/publish/source-code.html page to note
+  the latest release./li
+  liAdd new News item to ^/subversion/site/publish/news.html
+  announcing the release.  Add the same item to the News list on
+  ^/subversion/site/publish/index.html, also removing the oldest News item
+  from that page./li
   liCommit the modifications./li
+  liCreate or update the versioned documentation snapshots in
+^/site/publish/docs/api/X.Y and ^/site/publish/docs/javahl/X.Y, and
+ensure that the latest symlinks which are siblings of those
+directories always point to the directories of the latest release
+series.  Commit those changes, too./li
+
 /ol
 
 pIf you've made it this far, go and enjoy your $favorite_beverage now./p




svn commit: r963771 - /subversion/trunk/subversion/tests/cmdline/schedule_tests.py

2010-07-13 Thread cmpilato
Author: cmpilato
Date: Tue Jul 13 15:58:22 2010
New Revision: 963771

URL: http://svn.apache.org/viewvc?rev=963771view=rev
Log:
Add a regression test for a problem I reported on the dev list a few
months ago.  (On my birthday, as it turns out.)

* subversion/tests/cmdline/schedule_tests.py
  (delete_redelete_fudgery): New test.
  (test_list): Add XFail'd reference to new test.

Modified:
subversion/trunk/subversion/tests/cmdline/schedule_tests.py

Modified: subversion/trunk/subversion/tests/cmdline/schedule_tests.py
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/schedule_tests.py?rev=963771r1=963770r2=963771view=diff
==
--- subversion/trunk/subversion/tests/cmdline/schedule_tests.py (original)
+++ subversion/trunk/subversion/tests/cmdline/schedule_tests.py Tue Jul 13 
15:58:22 2010
@@ -646,6 +646,42 @@ def delete_non_existent(sbox):
   svntest.actions.run_and_verify_svn(None, None, svntest.verify.AnyOutput,
  'rm', '--force', 'non-existent')
 
+
+#--
+# Problem encountered by cmpilato when he inadvertantly upset an
+# 'svn rm --keep-local' and had to retry it.
+def delete_redelete_fudgery(sbox):
+  retry of manually upset --keep-local deletion
+
+  sbox.build()
+  wc_dir = sbox.wc_dir
+  B_path = os.path.join(wc_dir, 'A', 'B')
+
+  # Delete 'A/B' using --keep-local, then remove at the OS level.
+  svntest.actions.run_and_verify_svn(None, None, [],
+ 'rm', '--keep-local', B_path)
+  svntest.main.safe_rmtree(B_path)
+
+  # Update the tree.
+  #
+  ### When WC-NG is running in single-DB mode (one .svn directory and
+  ### database for the whole working copy), I suspect that this update
+  ### will change.  Today it re-adds the directory which we just
+  ### scheduled for deletion because the only record of that
+  ### scheduling is stored -- you guessed it -- the directory's .svn/
+  ### area... which we just deleted from disk.
+  ###
+  ### In single-DB-WC-NG-land, though, deleting the directory from
+  ### disk should have no bearing whatsoever on the scheduling
+  ### information stored now in the working copy root's one DB.  That
+  ### could change the whole flow of this test, possible leading us to
+  ### remove it as altogether irrelevant.  --cmpilato
+  svntest.actions.run_and_verify_svn(None, None, [], 'up', wc_dir)
+
+  # Now try to run
+  svntest.actions.run_and_verify_svn(None, None, [],
+ 'rm', '--keep-local', B_path)
+
 
 # Run the tests
 
@@ -665,6 +701,7 @@ test_list = [ None,
   add_recursive_already_versioned,
   fail_add_directory,
   delete_non_existent,
+  XFail(delete_redelete_fudgery),
  ]
 
 if __name__ == '__main__':




Re: svn commit: r963767 - /subversion/site/publish/docs/community-guide/releasing.part.html

2010-07-13 Thread Hyrum K. Wright
Bonus points if somebody writes a script to do all this website update
release magic for us.

On Tue, Jul 13, 2010 at 4:53 PM,  cmpil...@apache.org wrote:
 Author: cmpilato
 Date: Tue Jul 13 15:53:32 2010
 New Revision: 963767

 URL: http://svn.apache.org/viewvc?rev=963767view=rev
 Log:
 * site/publish/docs/community-guide/releasing.part.html
  (releasing-release): Update the website tweaking instructions, and
    add a reminder to update our published API doc snapshots as part of
    the release process, too.

 Modified:
    subversion/site/publish/docs/community-guide/releasing.part.html

 Modified: subversion/site/publish/docs/community-guide/releasing.part.html
 URL: 
 http://svn.apache.org/viewvc/subversion/site/publish/docs/community-guide/releasing.part.html?rev=963767r1=963766r2=963767view=diff
 ==
 --- subversion/site/publish/docs/community-guide/releasing.part.html 
 (original)
 +++ subversion/site/publish/docs/community-guide/releasing.part.html Tue Jul 
 13 15:53:32 2010
 @@ -1062,14 +1062,19 @@ freshmeat crew before it goes public./p

  pbUpdate the website/b/p
  ol
 -  liEdit the www/project_status.html file appropriately in /trunk
 -  *NOT* in the release branch and commit. Remember edit a search term
 -  at the end of release's issue link./li
 -  liUpdate the best available version on the front page and at the
 -  top of www/getting.html/li
 -  liUpdate the Latest Release section of www/index.html to point
 -  to the new announcement./li
 +  liEdit the ^/subversion/site/publish/source-code.html page to note
 +  the latest release./li
 +  liAdd new News item to ^/subversion/site/publish/news.html
 +  announcing the release.  Add the same item to the News list on
 +  ^/subversion/site/publish/index.html, also removing the oldest News item
 +  from that page./li
   liCommit the modifications./li
 +  liCreate or update the versioned documentation snapshots in
 +^/site/publish/docs/api/X.Y and ^/site/publish/docs/javahl/X.Y, and
 +ensure that the latest symlinks which are siblings of those
 +directories always point to the directories of the latest release
 +series.  Commit those changes, too./li
 +
  /ol

  pIf you've made it this far, go and enjoy your $favorite_beverage now./p





svn commit: r963779 - /subversion/site/publish/docs/index.html

2010-07-13 Thread cmpilato
Author: cmpilato
Date: Tue Jul 13 16:12:08 2010
New Revision: 963779

URL: http://svn.apache.org/viewvc?rev=963779view=rev
Log:
* site/publish/docs/index.html
  Upgrade the API documentation descriptions to h3's, and add a
  warning about the reliability and stability of the unreleased docs.

Modified:
subversion/site/publish/docs/index.html

Modified: subversion/site/publish/docs/index.html
URL: 
http://svn.apache.org/viewvc/subversion/site/publish/docs/index.html?rev=963779r1=963778r2=963779view=diff
==
--- subversion/site/publish/docs/index.html (original)
+++ subversion/site/publish/docs/index.html Tue Jul 13 16:12:08 2010
@@ -80,26 +80,33 @@
Subversion 1.6.0 libraries without your having to change your
software at all./p
 
-pLatest release:/p
+h3Latest release/h3
 
 ul
   lia href=api/latest/C API/a/li
   lia href=javahl/latest/JavaHL/a/li
 /ul
 
-pSubversion 1.6:/p
+h3Subversion 1.6/h3
 
 ul
   lia href=api/1.6/C API/a/li
   lia href=javahl/1.6/JavaHL/a/li
 /ul
 
-pBleeding-edge development (nightly generated from /trunk):/p
+h3Unreleased (1.7-dev)/h3
 
 ul
   lia href=http://people.apache.org/~hwright/svn/doc/api/trunk/;C 
API/a/li
 /ul
 
+pemNOTE: Unreleased documentation is provided by volunteers who
+   offer such as a service to (primarily) Subversion's own developers.
+   Such documentation has not been validated by Subversion's official
+   release procedure, does not necessarily describe stable APIs, and
+   is itself not guaranteed to be either accurate or complete.  Please
+   keep these facts in mind while using these documents./em/p
+
 /div !-- #api --
 
 /div !-- #site-content --




svn commit: r963814 - in /subversion/trunk/subversion: include/svn_diff.h libsvn_diff/parse-diff.c tests/libsvn_diff/parse-diff-test.c

2010-07-13 Thread dannas
Author: dannas
Date: Tue Jul 13 18:46:31 2010
New Revision: 963814

URL: http://svn.apache.org/viewvc?rev=963814view=rev
Log:
Start recording what operation is perfomed on a property in a patch.

* subversion/include/svn_diff.h
  (svn_prop_patch_t): New. Should only deal with the property part of a
patch.
  (svn_patch_t): Use an array of 'svn_prop_patch_t' instead of a
hash table of hunks for representing parsed property content.

* subversion/libsvn_diff/parse-diff.c
  (parse_next_hunk): Add 'prop_operation' parameter for recording if a
property patch was deleted, added or modified.
  (add_property_hunk): New.
  svn_diff_parse_next_patch): Call add_property_hunk() if we have a
property hunk. Use the new 'svn_prop_patch_t' type.
  
* subversion/tests/libsvn_diff/parse-diff-test.c
  (test_parse_property_diff,
   test_parse_property_and_text_diff): Adjust the tests to use the
new 'svn_prop_patch_t' type and loop over an array instead of 
fetching the properties from a hash table..

Modified:
subversion/trunk/subversion/include/svn_diff.h
subversion/trunk/subversion/libsvn_diff/parse-diff.c
subversion/trunk/subversion/tests/libsvn_diff/parse-diff-test.c

Modified: subversion/trunk/subversion/include/svn_diff.h
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_diff.h?rev=963814r1=963813r2=963814view=diff
==
--- subversion/trunk/subversion/include/svn_diff.h (original)
+++ subversion/trunk/subversion/include/svn_diff.h Tue Jul 13 18:46:31 2010
@@ -933,6 +933,22 @@ svn_linenum_t
 svn_diff_hunk_get_trailing_context(const svn_hunk_t *hunk);
 
 /**
+ * Data type to manage parsing of properties in patches.
+ * 
+ * @since New in 1.7. */
+typedef struct svn_prop_patch_t {
+  const char *name;
+
+  /** Represents the operation performed on the property */
+  svn_diff_operation_kind_t operation;
+
+  /**
+   * An array containing an svn_hunk_t object for each hunk parsed from the
+   * patch associated with our property name */
+  apr_array_header_t *hunks;
+} svn_prop_patch_t;
+
+/**
  * Data type to manage parsing of patches.
  *
  * @since New in 1.7. */
@@ -956,9 +972,9 @@ typedef struct svn_patch_t {
   apr_array_header_t *hunks;
 
   /**
-   * A hash table containing an array of svn_hunk_t object for each property
-   * parsed from the patch. The property names act as keys.  */
-  apr_hash_t *property_hunks;
+   * An array containing svn_patch_property_t object for each property
+   * parsed from the patch. */
+  apr_array_header_t *prop_patches;
 
   /**
* Represents the operation performed on the file. */

Modified: subversion/trunk/subversion/libsvn_diff/parse-diff.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_diff/parse-diff.c?rev=963814r1=963813r2=963814view=diff
==
--- subversion/trunk/subversion/libsvn_wc/adm_ops.c (original)
+++ subversion/trunk/subversion/libsvn_wc/adm_ops.c Tue Jul 13 21:08:49 2010
@@ -1272,8 +1272,8 @@ svn_wc_add4(svn_wc_context_t *wc_ctx,
   if (kind == svn_node_dir  !exists)
 {
   /* Lock on parent needs to be propogated into the child db. */
-  SVN_ERR(svn_wc__db_wclock_set(db, local_abspath, 0, scratch_pool));
-  SVN_ERR(svn_wc__db_temp_mark_locked(db, local_abspath, scratch_pool));
+  SVN_ERR(svn_wc__db_wclock_obtain(db, local_abspath, 0, FALSE,
+   scratch_pool));
 }
 
 #if (SVN_WC__VERSION  SVN_WC__PROPS_IN_DB)

Modified: subversion/trunk/subversion/libsvn_wc/lock.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/lock.c?rev=963863r1=963862r2=963863view=diff
==
--- subversion/trunk/subversion/libsvn_wc/lock.c (original)
+++ subversion/trunk/subversion/libsvn_wc/lock.c Tue Jul 13 21:08:49 2010
@@ -204,7 +204,7 @@ pool_cleanup_locked(void *p)
 {
   /* There is no remaining work, so we're good to remove any
  potential physical lock.  */
-
--- subversion/trunk/subversion/libsvn_wc/copy.c (original)
+++ subversion/trunk/subversion/libsvn_wc/copy.c Tue Jul 13 10:57:24 2010
@@ -482,8 +482,11 @@ copy_versioned_dir(svn_wc__db_t *db,
 }
 
   if (kind == svn_node_dir)
-/* All children, versioned and unversioned */
-SVN_ERR(svn_io_get_dirents2(children, src_abspath, scratch_pool));
+/* All children, versioned and unversioned.  We're only interested in the
+   names of the children, so we can pass TRUE as the only_check_type
+   param. */
+SVN_ERR(svn_io_get_dirents3(children, src_abspath, TRUE,
+scratch_pool, scratch_pool));
 
   /* Copy all the versioned children */
   SVN_ERR(svn_wc__db_read_children(versioned_children, db, src_abspath,




svn commit: r963697 - in /subversion/trunk/subversion: include/svn_io.h libsvn_subr/io.c

2010-07-13 Thread hwright
Author: hwright
Date: Tue Jul 13 12:43:55 2010
New Revision: 963697

URL: http://svn.apache.org/viewvc?rev=963697view=rev
Log:
Prevent API proliferation!

Deprecate the svn_io_get_dir_filenames() API, whose job can now be done by
svn_io_get_dirents3(), with the only_check_type parameter set to TRUE.
Specifically, the latter now avoids an extra stat() call on most platforms,
which was the purpose of svn_io_get_dir_filenames() to begin with.
(See r857526.)

* subversion/libsvn_subr/io.c
  (svn_io_get_dir_filenames): Make this a wrapper around get_dirents3().

* subversion/include/svn_io.h
  (svn_io_get_dir_filenames): Deprecate.

Modified:
subversion/trunk/subversion/include/svn_io.h
subversion/trunk/subversion/libsvn_subr/io.c

Modified: subversion/trunk/subversion/include/svn_io.h
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_io.h?rev=963697r1=963696r2=963697view=diff
==
--- subversion/trunk/subversion/libsvn_diff/parse-diff.c (original)
+++ subversion/trunk/subversion/libsvn_diff/parse-diff.c Tue Jul 13 18:46:31 
2010
@@ -501,14 +501,15 @@ parse_prop_name(const char **prop_name, 
 
 /* Return the next *HUNK from a PATCH, using STREAM to read data
  * from the patch file. If no hunk can be found, set *HUNK to NULL. If we
  * have a property hunk, PROP_NAME will be set. If we have a text hunk,
  * PROP_NAME will be NULL. If REVERSE is TRUE, invert the hunk while
  * parsing it. If IGNORE_WHiTESPACES is TRUE, let lines without leading
  * spaces be recognized as context lines.  Allocate results in RESULT_POOL.
  * Use SCRATCH_POOL for all other allocations. */
 static svn_error_t *
 parse_next_hunk(svn_hunk_t **hunk,
 const char **prop_name,
+svn_diff_operation_kind_t *prop_operation,
 svn_patch_t *patch,
 svn_stream_t *stream,
 svn_boolean_t reverse,
@@ -685,16 +686,19 @@ parse_next_hunk(svn_hunk_t **hunk,
 {
   SVN_ERR(parse_prop_name(prop_name, line-data, Added: ,
   result_pool));
+  *prop_operation = svn_diff_op_added;
 }
   else if (starts_with(line-data, Deleted: ))
 {
   SVN_ERR(parse_prop_name(prop_name, line-data, Deleted: ,
   result_pool));
+  *prop_operation = svn_diff_op_deleted;
 }
   else if (starts_with(line-data, Modified: ))
 {
@@ -501,14 +501,15 @@ parse_prop_name(const char **prop_name, 
 /* Return the next *HUNK from a PATCH, using STREAM to read data
  * from the patch file. If no hunk can be found, set *HUNK to NULL. If we
- * have a property hunk, PROP_NAME will be set. If we have a text hunk,
- * PROP_NAME will be NULL. If REVERSE is TRUE, invert the hunk while
- * parsing it. If IGNORE_WHiTESPACES is TRUE, let lines without leading
- * spaces be recognized as context lines.  Allocate results in RESULT_POOL.
- * Use SCRATCH_POOL for all other allocations. */
+ * have a property hunk, PROP_NAME and PROP_OPERATION will be set. If we
+ * have a text hunk, PROP_NAME will be NULL. If REVERSE is TRUE, invert the
+ * hunk while parsing it. If IGNORE_WHiTESPACES is TRUE, let lines without
+ * leading spaces be recognized as context lines.  Allocate results in
+ * RESULT_POOL.  Use SCRATCH_POOL for all other allocations. */
 static svn_error_t *
 parse_next_hunk(svn_hunk_t **hunk,
   SVN_ERR(parse_prop_name(prop_name, line-data, Modified: ,
   

svn commit: r963863 - in /subversion/trunk/subversion/libsvn_wc: adm_ops.c lock.c log.c upgrade.c wc-queries.sql wc_db.c wc_db.h wc_db_pdh.c wc_db_private.h

2010-07-13 Thread rhuijben
Author: rhuijben
Date: Tue Jul 13 21:08:49 2010
New Revision: 963863

URL: http://svn.apache.org/viewvc?rev=963863view=rev
Log:
Update the wc-db api for wclocks to have a single set of functions for
obtaining and releasing locks instead of a separate function for recording
and for knowing that we own the lock. Also add an initial implementation
for the lock behavior for when we switch to a single database.

* subversion/libsvn_wc/adm_ops.c
  (svn_wc_add4): Update caller.

* subversion/libsvn_wc/lock.c
  (pool_cleanup_locked): Update caller.
  (adm_access_alloc): Update caller.
  (close_single): Update caller.
  (svn_wc_adm_locked): Update caller.
  (svn_wc__write_check): Update caller.
  (svn_wc_locked2): Update caller.
  (svn_wc__acquire_write_lock): Update caller.
  (svn_wc__release_write_lock): Update caller and handle errors
on unlocking when we don't have a lock to keep current behavior.

* subversion/libsvn_wc/log.c
  (cleanup_internal): Obtain lock with steal_lock mode, instead of ignoring
the error.

* subversion/libsvn_wc/upgrade.c
  (upgrade_to_wcng): Update caller.

* subversion/libsvn_wc/wc-queries.sql
  (STMT_FIND_WC_LOCK): New query to obtain existing locks below a
new recursive lock.

* subversion/libsvn_wc/wc_db.c
  (relpath_op_depth): New helper function.
  (svn_wc__db_temp_forget_directory): Ignore error conditions to
keep current (mostly broken) behavior.
  (wclock_obtain_baton): New struct.
  (wclock_steal): New helper function.
  (wclock_obtain_cb): New transaction helper function.
  (svn_wc__db_wclock_set): Renamed to ...
  (svn_wc__db_wclock_obtain): ... this. Use a transaction to verify
current recursive locks and obtain a new lock. (Mostly unused in per
directory db layout).
  (svn_wc__db_wclock_remove): Renamed to ...
  (svn_wc__db_wclock_release): ... this. Verify lock ownership and add
support for single db operations.
  (svn_wc__db_temp_mark_locked): Remove function.
  (svn_wc__db_temp_own_lock): Rename to ...
  (svn_wc__db_wclock_owns_lock): ... this and allow checking for checking a root
and/or multiple levels.

* subversion/libsvn_wc/wc_db.h
  (svn_wc__db_wclock_set): Rename to ...
  (svn_wc__db_wclock_obtain): ... this and document levels_to_lock.
  (svn_wc__db_wclocked): Add documentation.
  (svn_wc__db_wclock_remove): Rename to ...
  (svn_wc__db_wclock_release): ... this.
  (svn_wc__db_wclock_owns_lock): New function.
  (svn_wc__db_temp_mark_locked): Remove function.
  (svn_wc__db_temp_own_lock): Remove function.

* subversion/libsvn_wc/wc_db_pdh.c
  (determine_obstructed_file): #undef when using single_db.
  (svn_wc__db_pdh_create_wcroot): Initialize new lock store if single db.
  (svn_wc__db_pdh_parse_local_abspath): Disable obstruction check on
single db.

* subversion/libsvn_wc/wc_db_private.h
  (svn_wc__db_wclock_t): New struct.
  (svn_wc__db_wcroot_t): Name struct (for debugging and svn diff -x -p)
Add array of owned locks.
  (svn_wc__db_pdh_t): Remove obstructed_file and locked for single db.

Modified:
subversion/trunk/subversion/libsvn_wc/adm_ops.c
subversion/trunk/subversion/libsvn_wc/lock.c
subversion/trunk/subversion/libsvn_wc/log.c
subversion/trunk/subversion/libsvn_wc/upgrade.c
subversion/trunk/subversion/libsvn_wc/wc-queries.sql
subversion/trunk/subversion/libsvn_wc/wc_db.c
subversion/trunk/subversion/libsvn_wc/wc_db.h
subversion/trunk/subversion/libsvn_wc/wc_db_pdh.c
subversion/trunk/subversion/libsvn_wc/wc_db_private.h

Modified: subversion/trunk/subversion/libsvn_wc/adm_ops.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/adm_ops.c?rev=963863r1=963862r2=963863view=diff
==